# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SystemUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'abbreviation': 'str',
        'is_paused': 'bool',
        'description': 'str',
        'is_visible': 'bool',
        'active': 'bool',
        'cds_master_system_ids': 'list[str]',
        'cds_base_station_ids': 'list[int]'
    }

    attribute_map = {
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'is_paused': 'IsPaused',
        'description': 'Description',
        'is_visible': 'IsVisible',
        'active': 'Active',
        'cds_master_system_ids': 'CdsMasterSystemIds',
        'cds_base_station_ids': 'CdsBaseStationIds'
    }

    def __init__(self, name=None, abbreviation=None, is_paused=None, description=None, is_visible=None, active=None, cds_master_system_ids=None, cds_base_station_ids=None):  # noqa: E501
        """SystemUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._abbreviation = None
        self._is_paused = None
        self._description = None
        self._is_visible = None
        self._active = None
        self._cds_master_system_ids = None
        self._cds_base_station_ids = None
        self.discriminator = None
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.is_paused = is_paused
        if description is not None:
            self.description = description
        self.is_visible = is_visible
        self.active = active
        if cds_master_system_ids is not None:
            self.cds_master_system_ids = cds_master_system_ids
        if cds_base_station_ids is not None:
            self.cds_base_station_ids = cds_base_station_ids

    @property
    def name(self):
        """Gets the name of this SystemUpdateRequest.  # noqa: E501


        :return: The name of this SystemUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SystemUpdateRequest.


        :param name: The name of this SystemUpdateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this SystemUpdateRequest.  # noqa: E501


        :return: The abbreviation of this SystemUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this SystemUpdateRequest.


        :param abbreviation: The abbreviation of this SystemUpdateRequest.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def is_paused(self):
        """Gets the is_paused of this SystemUpdateRequest.  # noqa: E501


        :return: The is_paused of this SystemUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this SystemUpdateRequest.


        :param is_paused: The is_paused of this SystemUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def description(self):
        """Gets the description of this SystemUpdateRequest.  # noqa: E501


        :return: The description of this SystemUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SystemUpdateRequest.


        :param description: The description of this SystemUpdateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def is_visible(self):
        """Gets the is_visible of this SystemUpdateRequest.  # noqa: E501


        :return: The is_visible of this SystemUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """Sets the is_visible of this SystemUpdateRequest.


        :param is_visible: The is_visible of this SystemUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_visible is None:
            raise ValueError("Invalid value for `is_visible`, must not be `None`")  # noqa: E501

        self._is_visible = is_visible

    @property
    def active(self):
        """Gets the active of this SystemUpdateRequest.  # noqa: E501


        :return: The active of this SystemUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this SystemUpdateRequest.


        :param active: The active of this SystemUpdateRequest.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def cds_master_system_ids(self):
        """Gets the cds_master_system_ids of this SystemUpdateRequest.  # noqa: E501


        :return: The cds_master_system_ids of this SystemUpdateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._cds_master_system_ids

    @cds_master_system_ids.setter
    def cds_master_system_ids(self, cds_master_system_ids):
        """Sets the cds_master_system_ids of this SystemUpdateRequest.


        :param cds_master_system_ids: The cds_master_system_ids of this SystemUpdateRequest.  # noqa: E501
        :type: list[str]
        """

        self._cds_master_system_ids = cds_master_system_ids

    @property
    def cds_base_station_ids(self):
        """Gets the cds_base_station_ids of this SystemUpdateRequest.  # noqa: E501


        :return: The cds_base_station_ids of this SystemUpdateRequest.  # noqa: E501
        :rtype: list[int]
        """
        return self._cds_base_station_ids

    @cds_base_station_ids.setter
    def cds_base_station_ids(self, cds_base_station_ids):
        """Sets the cds_base_station_ids of this SystemUpdateRequest.


        :param cds_base_station_ids: The cds_base_station_ids of this SystemUpdateRequest.  # noqa: E501
        :type: list[int]
        """

        self._cds_base_station_ids = cds_base_station_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SystemUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class FilesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_file(self, **kwargs):  # noqa: E501
        """Creates a file  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_file(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ContentType file_type:
        :param str display_name:
        :param str parent_folder_id:
        :param str description:
        :param str location_id:
        :param str corporation_id:
        :param list[str] group_ids:
        :param str files:
        :return: PictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_file_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_file_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_file_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a file  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_file_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ContentType file_type:
        :param str display_name:
        :param str parent_folder_id:
        :param str description:
        :param str location_id:
        :param str corporation_id:
        :param list[str] group_ids:
        :param str files:
        :return: PictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_type', 'display_name', 'parent_folder_id', 'description', 'location_id', 'corporation_id', 'group_ids', 'files']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_file" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file_type' in params:
            form_params.append(('FileType', params['file_type']))  # noqa: E501
        if 'display_name' in params:
            form_params.append(('DisplayName', params['display_name']))  # noqa: E501
        if 'parent_folder_id' in params:
            form_params.append(('ParentFolderId', params['parent_folder_id']))  # noqa: E501
        if 'description' in params:
            form_params.append(('Description', params['description']))  # noqa: E501
        if 'location_id' in params:
            form_params.append(('LocationId', params['location_id']))  # noqa: E501
        if 'corporation_id' in params:
            form_params.append(('CorporationId', params['corporation_id']))  # noqa: E501
        if 'group_ids' in params:
            form_params.append(('GroupIds', params['group_ids']))  # noqa: E501
            collection_formats['GroupIds'] = 'multi'  # noqa: E501
        if 'files' in params:
            local_var_files['files'] = params['files']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PictureFileMetadataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_file(self, file_id, **kwargs):  # noqa: E501
        """Deletes a file  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: File id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_file_with_http_info(file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_file_with_http_info(file_id, **kwargs)  # noqa: E501
            return data

    def delete_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Deletes a file  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: File id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `delete_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in params:
            path_params['fileId'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files/{fileId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_corporation_files(self, corporation_id, **kwargs):  # noqa: E501
        """Gets all files for a corporation  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_corporation_files(corporation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str corporation_id: (required)
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FileType` | ContentType | `eq, neq, in` | | `IsRootFolder` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `ParentFolderId` | Guid? | `eq, neq, in, lt, gt, leq, geq` | | `TagId` | Guid | `eq, neq, in` | | `TagName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `CreationDate` | DateTime | | `DisplayName` | String | | `FileName` | String | | `UpdateDate` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`, `DisplayName`, `TagName`.
        :return: PagedResultsModelPictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_corporation_files_with_http_info(corporation_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_corporation_files_with_http_info(corporation_id, **kwargs)  # noqa: E501
            return data

    def get_corporation_files_with_http_info(self, corporation_id, **kwargs):  # noqa: E501
        """Gets all files for a corporation  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_corporation_files_with_http_info(corporation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str corporation_id: (required)
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FileType` | ContentType | `eq, neq, in` | | `IsRootFolder` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `ParentFolderId` | Guid? | `eq, neq, in, lt, gt, leq, geq` | | `TagId` | Guid | `eq, neq, in` | | `TagName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `CreationDate` | DateTime | | `DisplayName` | String | | `FileName` | String | | `UpdateDate` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`, `DisplayName`, `TagName`.
        :return: PagedResultsModelPictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['corporation_id', 'group_ids', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_corporation_files" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'corporation_id' is set
        if ('corporation_id' not in params or
                params['corporation_id'] is None):
            raise ValueError("Missing the required parameter `corporation_id` when calling `get_corporation_files`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'corporation_id' in params:
            path_params['corporationId'] = params['corporation_id']  # noqa: E501

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files/corporations/{corporationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelPictureFileMetadataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file(self, id, **kwargs):  # noqa: E501
        """Gets a file  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Corporation User  Location Admin  Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: PictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_file_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_file_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_file_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a file  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Corporation User  Location Admin  Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: PictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PictureFileMetadataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file_object(self, object_filename, **kwargs):  # noqa: E501
        """Gets a file object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_object(object_filename, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_filename: Filename (key) of requested object (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_file_object_with_http_info(object_filename, **kwargs)  # noqa: E501
        else:
            (data) = self.get_file_object_with_http_info(object_filename, **kwargs)  # noqa: E501
            return data

    def get_file_object_with_http_info(self, object_filename, **kwargs):  # noqa: E501
        """Gets a file object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_object_with_http_info(object_filename, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_filename: Filename (key) of requested object (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['object_filename']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file_object" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'object_filename' is set
        if ('object_filename' not in params or
                params['object_filename'] is None):
            raise ValueError("Missing the required parameter `object_filename` when calling `get_file_object`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'object_filename' in params:
            path_params['objectFilename'] = params['object_filename']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files/object/{objectFilename}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_files(self, **kwargs):  # noqa: E501
        """Get all the files  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Corporation User  Location Admin  Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_files(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FileType` | ContentType | `eq, neq, in` | | `IsRootFolder` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `ParentFolderId` | Guid? | `eq, neq, in, lt, gt, leq, geq` | | `TagId` | Guid | `eq, neq, in` | | `TagName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `CreationDate` | DateTime | | `DisplayName` | String | | `FileName` | String | | `UpdateDate` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`, `DisplayName`, `TagName`.
        :return: PagedResultsModelPictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_files_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_files_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_files_with_http_info(self, **kwargs):  # noqa: E501
        """Get all the files  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Corporation User  Location Admin  Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_files_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FileType` | ContentType | `eq, neq, in` | | `IsRootFolder` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `ParentFolderId` | Guid? | `eq, neq, in, lt, gt, leq, geq` | | `TagId` | Guid | `eq, neq, in` | | `TagName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `CreationDate` | DateTime | | `DisplayName` | String | | `FileName` | String | | `UpdateDate` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`, `DisplayName`, `TagName`.
        :return: PagedResultsModelPictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_ids', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_files" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelPictureFileMetadataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_location_files(self, location_id, **kwargs):  # noqa: E501
        """Gets all files for a location  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Corporation User  Location Admin  Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_location_files(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: (required)
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FileType` | ContentType | `eq, neq, in` | | `IsRootFolder` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `ParentFolderId` | Guid? | `eq, neq, in, lt, gt, leq, geq` | | `TagId` | Guid | `eq, neq, in` | | `TagName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `CreationDate` | DateTime | | `DisplayName` | String | | `FileName` | String | | `UpdateDate` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`, `DisplayName`, `TagName`.
        :return: PagedResultsModelPictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_location_files_with_http_info(location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_location_files_with_http_info(location_id, **kwargs)  # noqa: E501
            return data

    def get_location_files_with_http_info(self, location_id, **kwargs):  # noqa: E501
        """Gets all files for a location  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Corporation User  Location Admin  Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_location_files_with_http_info(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: (required)
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FileType` | ContentType | `eq, neq, in` | | `IsRootFolder` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `ParentFolderId` | Guid? | `eq, neq, in, lt, gt, leq, geq` | | `TagId` | Guid | `eq, neq, in` | | `TagName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `CreationDate` | DateTime | | `DisplayName` | String | | `FileName` | String | | `UpdateDate` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`, `DisplayName`, `TagName`.
        :return: PagedResultsModelPictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['location_id', 'group_ids', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_location_files" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `get_location_files`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'location_id' in params:
            path_params['locationId'] = params['location_id']  # noqa: E501

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files/locations/{locationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelPictureFileMetadataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def move_files(self, **kwargs):  # noqa: E501
        """Moves files to a folder  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.move_files(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MoveFilesRequest body: Move Request
        :return: MoveFilesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.move_files_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.move_files_with_http_info(**kwargs)  # noqa: E501
            return data

    def move_files_with_http_info(self, **kwargs):  # noqa: E501
        """Moves files to a folder  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.move_files_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MoveFilesRequest body: Move Request
        :return: MoveFilesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method move_files" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files/move', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MoveFilesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_file(self, file_id, **kwargs):  # noqa: E501
        """Update a file  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: (required)
        :param FilesUpdateRequest body: File object to update
        :return: PictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_file_with_http_info(file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_file_with_http_info(file_id, **kwargs)  # noqa: E501
            return data

    def update_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Update a file  # noqa: E501

        Required Permissions:  System Admin / Sentry  Corporation Admin  Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_id: (required)
        :param FilesUpdateRequest body: File object to update
        :return: PictureFileMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `update_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in params:
            path_params['fileId'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Files/{fileId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PictureFileMetadataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HubResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'receiver': 'ReceiverChild',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'serial_number': 'str',
        'name': 'str',
        'power_type': 'HubPowerType',
        'firmware_version': 'str',
        'hub_type': 'HubType',
        'created': 'datetime',
        'updated': 'datetime',
        'packet_success_rate': 'float',
        'wireless_efficiency': 'float',
        'triggering_enabled': 'bool',
        'ports': 'list[HubPortChild]',
        'is_online': 'bool',
        'last_update_time': 'datetime',
        'temperature': 'float',
        'voltage': 'float'
    }

    attribute_map = {
        'id': 'Id',
        'receiver': 'Receiver',
        'location': 'Location',
        'corporation': 'Corporation',
        'serial_number': 'SerialNumber',
        'name': 'Name',
        'power_type': 'PowerType',
        'firmware_version': 'FirmwareVersion',
        'hub_type': 'HubType',
        'created': 'Created',
        'updated': 'Updated',
        'packet_success_rate': 'PacketSuccessRate',
        'wireless_efficiency': 'WirelessEfficiency',
        'triggering_enabled': 'TriggeringEnabled',
        'ports': 'Ports',
        'is_online': 'IsOnline',
        'last_update_time': 'LastUpdateTime',
        'temperature': 'Temperature',
        'voltage': 'Voltage'
    }

    def __init__(self, id=None, receiver=None, location=None, corporation=None, serial_number=None, name=None, power_type=None, firmware_version=None, hub_type=None, created=None, updated=None, packet_success_rate=None, wireless_efficiency=None, triggering_enabled=None, ports=None, is_online=None, last_update_time=None, temperature=None, voltage=None):  # noqa: E501
        """HubResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._receiver = None
        self._location = None
        self._corporation = None
        self._serial_number = None
        self._name = None
        self._power_type = None
        self._firmware_version = None
        self._hub_type = None
        self._created = None
        self._updated = None
        self._packet_success_rate = None
        self._wireless_efficiency = None
        self._triggering_enabled = None
        self._ports = None
        self._is_online = None
        self._last_update_time = None
        self._temperature = None
        self._voltage = None
        self.discriminator = None
        self.id = id
        if receiver is not None:
            self.receiver = receiver
        self.location = location
        self.corporation = corporation
        self.serial_number = serial_number
        if name is not None:
            self.name = name
        if power_type is not None:
            self.power_type = power_type
        if firmware_version is not None:
            self.firmware_version = firmware_version
        if hub_type is not None:
            self.hub_type = hub_type
        self.created = created
        self.updated = updated
        self.packet_success_rate = packet_success_rate
        self.wireless_efficiency = wireless_efficiency
        self.triggering_enabled = triggering_enabled
        self.ports = ports
        if is_online is not None:
            self.is_online = is_online
        if last_update_time is not None:
            self.last_update_time = last_update_time
        if temperature is not None:
            self.temperature = temperature
        if voltage is not None:
            self.voltage = voltage

    @property
    def id(self):
        """Gets the id of this HubResponse.  # noqa: E501


        :return: The id of this HubResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HubResponse.


        :param id: The id of this HubResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def receiver(self):
        """Gets the receiver of this HubResponse.  # noqa: E501


        :return: The receiver of this HubResponse.  # noqa: E501
        :rtype: ReceiverChild
        """
        return self._receiver

    @receiver.setter
    def receiver(self, receiver):
        """Sets the receiver of this HubResponse.


        :param receiver: The receiver of this HubResponse.  # noqa: E501
        :type: ReceiverChild
        """

        self._receiver = receiver

    @property
    def location(self):
        """Gets the location of this HubResponse.  # noqa: E501


        :return: The location of this HubResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this HubResponse.


        :param location: The location of this HubResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this HubResponse.  # noqa: E501


        :return: The corporation of this HubResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this HubResponse.


        :param corporation: The corporation of this HubResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def serial_number(self):
        """Gets the serial_number of this HubResponse.  # noqa: E501


        :return: The serial_number of this HubResponse.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this HubResponse.


        :param serial_number: The serial_number of this HubResponse.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def name(self):
        """Gets the name of this HubResponse.  # noqa: E501


        :return: The name of this HubResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HubResponse.


        :param name: The name of this HubResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def power_type(self):
        """Gets the power_type of this HubResponse.  # noqa: E501


        :return: The power_type of this HubResponse.  # noqa: E501
        :rtype: HubPowerType
        """
        return self._power_type

    @power_type.setter
    def power_type(self, power_type):
        """Sets the power_type of this HubResponse.


        :param power_type: The power_type of this HubResponse.  # noqa: E501
        :type: HubPowerType
        """

        self._power_type = power_type

    @property
    def firmware_version(self):
        """Gets the firmware_version of this HubResponse.  # noqa: E501


        :return: The firmware_version of this HubResponse.  # noqa: E501
        :rtype: str
        """
        return self._firmware_version

    @firmware_version.setter
    def firmware_version(self, firmware_version):
        """Sets the firmware_version of this HubResponse.


        :param firmware_version: The firmware_version of this HubResponse.  # noqa: E501
        :type: str
        """

        self._firmware_version = firmware_version

    @property
    def hub_type(self):
        """Gets the hub_type of this HubResponse.  # noqa: E501


        :return: The hub_type of this HubResponse.  # noqa: E501
        :rtype: HubType
        """
        return self._hub_type

    @hub_type.setter
    def hub_type(self, hub_type):
        """Sets the hub_type of this HubResponse.


        :param hub_type: The hub_type of this HubResponse.  # noqa: E501
        :type: HubType
        """

        self._hub_type = hub_type

    @property
    def created(self):
        """Gets the created of this HubResponse.  # noqa: E501


        :return: The created of this HubResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this HubResponse.


        :param created: The created of this HubResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this HubResponse.  # noqa: E501


        :return: The updated of this HubResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this HubResponse.


        :param updated: The updated of this HubResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def packet_success_rate(self):
        """Gets the packet_success_rate of this HubResponse.  # noqa: E501


        :return: The packet_success_rate of this HubResponse.  # noqa: E501
        :rtype: float
        """
        return self._packet_success_rate

    @packet_success_rate.setter
    def packet_success_rate(self, packet_success_rate):
        """Sets the packet_success_rate of this HubResponse.


        :param packet_success_rate: The packet_success_rate of this HubResponse.  # noqa: E501
        :type: float
        """
        if packet_success_rate is None:
            raise ValueError("Invalid value for `packet_success_rate`, must not be `None`")  # noqa: E501

        self._packet_success_rate = packet_success_rate

    @property
    def wireless_efficiency(self):
        """Gets the wireless_efficiency of this HubResponse.  # noqa: E501


        :return: The wireless_efficiency of this HubResponse.  # noqa: E501
        :rtype: float
        """
        return self._wireless_efficiency

    @wireless_efficiency.setter
    def wireless_efficiency(self, wireless_efficiency):
        """Sets the wireless_efficiency of this HubResponse.


        :param wireless_efficiency: The wireless_efficiency of this HubResponse.  # noqa: E501
        :type: float
        """
        if wireless_efficiency is None:
            raise ValueError("Invalid value for `wireless_efficiency`, must not be `None`")  # noqa: E501

        self._wireless_efficiency = wireless_efficiency

    @property
    def triggering_enabled(self):
        """Gets the triggering_enabled of this HubResponse.  # noqa: E501


        :return: The triggering_enabled of this HubResponse.  # noqa: E501
        :rtype: bool
        """
        return self._triggering_enabled

    @triggering_enabled.setter
    def triggering_enabled(self, triggering_enabled):
        """Sets the triggering_enabled of this HubResponse.


        :param triggering_enabled: The triggering_enabled of this HubResponse.  # noqa: E501
        :type: bool
        """
        if triggering_enabled is None:
            raise ValueError("Invalid value for `triggering_enabled`, must not be `None`")  # noqa: E501

        self._triggering_enabled = triggering_enabled

    @property
    def ports(self):
        """Gets the ports of this HubResponse.  # noqa: E501


        :return: The ports of this HubResponse.  # noqa: E501
        :rtype: list[HubPortChild]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this HubResponse.


        :param ports: The ports of this HubResponse.  # noqa: E501
        :type: list[HubPortChild]
        """
        if ports is None:
            raise ValueError("Invalid value for `ports`, must not be `None`")  # noqa: E501

        self._ports = ports

    @property
    def is_online(self):
        """Gets the is_online of this HubResponse.  # noqa: E501


        :return: The is_online of this HubResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_online

    @is_online.setter
    def is_online(self, is_online):
        """Sets the is_online of this HubResponse.


        :param is_online: The is_online of this HubResponse.  # noqa: E501
        :type: bool
        """

        self._is_online = is_online

    @property
    def last_update_time(self):
        """Gets the last_update_time of this HubResponse.  # noqa: E501


        :return: The last_update_time of this HubResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this HubResponse.


        :param last_update_time: The last_update_time of this HubResponse.  # noqa: E501
        :type: datetime
        """

        self._last_update_time = last_update_time

    @property
    def temperature(self):
        """Gets the temperature of this HubResponse.  # noqa: E501


        :return: The temperature of this HubResponse.  # noqa: E501
        :rtype: float
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this HubResponse.


        :param temperature: The temperature of this HubResponse.  # noqa: E501
        :type: float
        """

        self._temperature = temperature

    @property
    def voltage(self):
        """Gets the voltage of this HubResponse.  # noqa: E501


        :return: The voltage of this HubResponse.  # noqa: E501
        :rtype: float
        """
        return self._voltage

    @voltage.setter
    def voltage(self, voltage):
        """Sets the voltage of this HubResponse.


        :param voltage: The voltage of this HubResponse.  # noqa: E501
        :type: float
        """

        self._voltage = voltage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HubResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.systems_api import SystemsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestSystemsApi(unittest.TestCase):
    """SystemsApi unit test stubs"""

    def setUp(self):
        self.api = SystemsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_system(self):
        """Test case for create_system

        Creates a system  # noqa: E501
        """
        pass

    def test_get_asset_status_summaries_for_system(self):
        """Test case for get_asset_status_summaries_for_system

        Gets asset status summary for a system  # noqa: E501
        """
        pass

    def test_get_asset_status_summaries_for_systems(self):
        """Test case for get_asset_status_summaries_for_systems

        Gets asset status summary for systems  # noqa: E501
        """
        pass

    def test_get_system(self):
        """Test case for get_system

        Gets a system  # noqa: E501
        """
        pass

    def test_get_system_overview(self):
        """Test case for get_system_overview

        Gets the system overview for a single system  # noqa: E501
        """
        pass

    def test_get_systems(self):
        """Test case for get_systems

        Gets systems  # noqa: E501
        """
        pass

    def test_get_systems_overview(self):
        """Test case for get_systems_overview

        Gets all system overviews  # noqa: E501
        """
        pass

    def test_update_system(self):
        """Test case for update_system

        Updates a system  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LongBurstRequestChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'long_burst_request_id': 'int',
        'long_burst_request_status': 'LongBurstRequestState',
        'requested_time': 'datetime',
        'completed_time': 'datetime',
        'requested_by_user': 'UserChild',
        'x_axis_long_burst_file': 'str',
        'y_axis_long_burst_file': 'str'
    }

    attribute_map = {
        'long_burst_request_id': 'LongBurstRequestId',
        'long_burst_request_status': 'LongBurstRequestStatus',
        'requested_time': 'RequestedTime',
        'completed_time': 'CompletedTime',
        'requested_by_user': 'RequestedByUser',
        'x_axis_long_burst_file': 'XAxisLongBurstFile',
        'y_axis_long_burst_file': 'YAxisLongBurstFile'
    }

    def __init__(self, long_burst_request_id=None, long_burst_request_status=None, requested_time=None, completed_time=None, requested_by_user=None, x_axis_long_burst_file=None, y_axis_long_burst_file=None):  # noqa: E501
        """LongBurstRequestChild - a model defined in Swagger"""  # noqa: E501
        self._long_burst_request_id = None
        self._long_burst_request_status = None
        self._requested_time = None
        self._completed_time = None
        self._requested_by_user = None
        self._x_axis_long_burst_file = None
        self._y_axis_long_burst_file = None
        self.discriminator = None
        if long_burst_request_id is not None:
            self.long_burst_request_id = long_burst_request_id
        if long_burst_request_status is not None:
            self.long_burst_request_status = long_burst_request_status
        if requested_time is not None:
            self.requested_time = requested_time
        if completed_time is not None:
            self.completed_time = completed_time
        if requested_by_user is not None:
            self.requested_by_user = requested_by_user
        if x_axis_long_burst_file is not None:
            self.x_axis_long_burst_file = x_axis_long_burst_file
        if y_axis_long_burst_file is not None:
            self.y_axis_long_burst_file = y_axis_long_burst_file

    @property
    def long_burst_request_id(self):
        """Gets the long_burst_request_id of this LongBurstRequestChild.  # noqa: E501


        :return: The long_burst_request_id of this LongBurstRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._long_burst_request_id

    @long_burst_request_id.setter
    def long_burst_request_id(self, long_burst_request_id):
        """Sets the long_burst_request_id of this LongBurstRequestChild.


        :param long_burst_request_id: The long_burst_request_id of this LongBurstRequestChild.  # noqa: E501
        :type: int
        """

        self._long_burst_request_id = long_burst_request_id

    @property
    def long_burst_request_status(self):
        """Gets the long_burst_request_status of this LongBurstRequestChild.  # noqa: E501


        :return: The long_burst_request_status of this LongBurstRequestChild.  # noqa: E501
        :rtype: LongBurstRequestState
        """
        return self._long_burst_request_status

    @long_burst_request_status.setter
    def long_burst_request_status(self, long_burst_request_status):
        """Sets the long_burst_request_status of this LongBurstRequestChild.


        :param long_burst_request_status: The long_burst_request_status of this LongBurstRequestChild.  # noqa: E501
        :type: LongBurstRequestState
        """

        self._long_burst_request_status = long_burst_request_status

    @property
    def requested_time(self):
        """Gets the requested_time of this LongBurstRequestChild.  # noqa: E501


        :return: The requested_time of this LongBurstRequestChild.  # noqa: E501
        :rtype: datetime
        """
        return self._requested_time

    @requested_time.setter
    def requested_time(self, requested_time):
        """Sets the requested_time of this LongBurstRequestChild.


        :param requested_time: The requested_time of this LongBurstRequestChild.  # noqa: E501
        :type: datetime
        """

        self._requested_time = requested_time

    @property
    def completed_time(self):
        """Gets the completed_time of this LongBurstRequestChild.  # noqa: E501


        :return: The completed_time of this LongBurstRequestChild.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_time

    @completed_time.setter
    def completed_time(self, completed_time):
        """Sets the completed_time of this LongBurstRequestChild.


        :param completed_time: The completed_time of this LongBurstRequestChild.  # noqa: E501
        :type: datetime
        """

        self._completed_time = completed_time

    @property
    def requested_by_user(self):
        """Gets the requested_by_user of this LongBurstRequestChild.  # noqa: E501


        :return: The requested_by_user of this LongBurstRequestChild.  # noqa: E501
        :rtype: UserChild
        """
        return self._requested_by_user

    @requested_by_user.setter
    def requested_by_user(self, requested_by_user):
        """Sets the requested_by_user of this LongBurstRequestChild.


        :param requested_by_user: The requested_by_user of this LongBurstRequestChild.  # noqa: E501
        :type: UserChild
        """

        self._requested_by_user = requested_by_user

    @property
    def x_axis_long_burst_file(self):
        """Gets the x_axis_long_burst_file of this LongBurstRequestChild.  # noqa: E501


        :return: The x_axis_long_burst_file of this LongBurstRequestChild.  # noqa: E501
        :rtype: str
        """
        return self._x_axis_long_burst_file

    @x_axis_long_burst_file.setter
    def x_axis_long_burst_file(self, x_axis_long_burst_file):
        """Sets the x_axis_long_burst_file of this LongBurstRequestChild.


        :param x_axis_long_burst_file: The x_axis_long_burst_file of this LongBurstRequestChild.  # noqa: E501
        :type: str
        """

        self._x_axis_long_burst_file = x_axis_long_burst_file

    @property
    def y_axis_long_burst_file(self):
        """Gets the y_axis_long_burst_file of this LongBurstRequestChild.  # noqa: E501


        :return: The y_axis_long_burst_file of this LongBurstRequestChild.  # noqa: E501
        :rtype: str
        """
        return self._y_axis_long_burst_file

    @y_axis_long_burst_file.setter
    def y_axis_long_burst_file(self, y_axis_long_burst_file):
        """Sets the y_axis_long_burst_file of this LongBurstRequestChild.


        :param y_axis_long_burst_file: The y_axis_long_burst_file of this LongBurstRequestChild.  # noqa: E501
        :type: str
        """

        self._y_axis_long_burst_file = y_axis_long_burst_file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LongBurstRequestChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LongBurstRequestChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetCategoryCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_type_id': 'int',
        'parent_category_id': 'int',
        'short_name': 'str'
    }

    attribute_map = {
        'asset_type_id': 'AssetTypeId',
        'parent_category_id': 'ParentCategoryId',
        'short_name': 'ShortName'
    }

    def __init__(self, asset_type_id=None, parent_category_id=None, short_name=None):  # noqa: E501
        """AssetCategoryCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._asset_type_id = None
        self._parent_category_id = None
        self._short_name = None
        self.discriminator = None
        self.asset_type_id = asset_type_id
        if parent_category_id is not None:
            self.parent_category_id = parent_category_id
        self.short_name = short_name

    @property
    def asset_type_id(self):
        """Gets the asset_type_id of this AssetCategoryCreateRequest.  # noqa: E501

        The Asset Type connected to the category  # noqa: E501

        :return: The asset_type_id of this AssetCategoryCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._asset_type_id

    @asset_type_id.setter
    def asset_type_id(self, asset_type_id):
        """Sets the asset_type_id of this AssetCategoryCreateRequest.

        The Asset Type connected to the category  # noqa: E501

        :param asset_type_id: The asset_type_id of this AssetCategoryCreateRequest.  # noqa: E501
        :type: int
        """
        if asset_type_id is None:
            raise ValueError("Invalid value for `asset_type_id`, must not be `None`")  # noqa: E501

        self._asset_type_id = asset_type_id

    @property
    def parent_category_id(self):
        """Gets the parent_category_id of this AssetCategoryCreateRequest.  # noqa: E501

        An optional parent category  # noqa: E501

        :return: The parent_category_id of this AssetCategoryCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._parent_category_id

    @parent_category_id.setter
    def parent_category_id(self, parent_category_id):
        """Sets the parent_category_id of this AssetCategoryCreateRequest.

        An optional parent category  # noqa: E501

        :param parent_category_id: The parent_category_id of this AssetCategoryCreateRequest.  # noqa: E501
        :type: int
        """

        self._parent_category_id = parent_category_id

    @property
    def short_name(self):
        """Gets the short_name of this AssetCategoryCreateRequest.  # noqa: E501

        The short name of the category.   The full name is generated automatically   when a parent category is supplied.  # noqa: E501

        :return: The short_name of this AssetCategoryCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._short_name

    @short_name.setter
    def short_name(self, short_name):
        """Sets the short_name of this AssetCategoryCreateRequest.

        The short name of the category.   The full name is generated automatically   when a parent category is supplied.  # noqa: E501

        :param short_name: The short_name of this AssetCategoryCreateRequest.  # noqa: E501
        :type: str
        """
        if short_name is None:
            raise ValueError("Invalid value for `short_name`, must not be `None`")  # noqa: E501

        self._short_name = short_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetCategoryCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetCategoryCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SessionCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'system_id': 'str',
        'custom_filter_ids': 'list[str]',
        'indicator_types': 'list[MetricTypeCodes]',
        'measure_ofs': 'list[SensorRoleTypeCodes]',
        'group_ids': 'list[str]',
        'selected_indicator_ids': 'list[str]',
        'selected_point': 'SessionSelectedPointChild',
        'time_range': 'SessionTimeRangeChild',
        'is_custom_filter_type': 'bool'
    }

    attribute_map = {
        'system_id': 'SystemId',
        'custom_filter_ids': 'CustomFilterIds',
        'indicator_types': 'IndicatorTypes',
        'measure_ofs': 'MeasureOfs',
        'group_ids': 'GroupIds',
        'selected_indicator_ids': 'SelectedIndicatorIds',
        'selected_point': 'SelectedPoint',
        'time_range': 'TimeRange',
        'is_custom_filter_type': 'IsCustomFilterType'
    }

    def __init__(self, system_id=None, custom_filter_ids=None, indicator_types=None, measure_ofs=None, group_ids=None, selected_indicator_ids=None, selected_point=None, time_range=None, is_custom_filter_type=None):  # noqa: E501
        """SessionCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._system_id = None
        self._custom_filter_ids = None
        self._indicator_types = None
        self._measure_ofs = None
        self._group_ids = None
        self._selected_indicator_ids = None
        self._selected_point = None
        self._time_range = None
        self._is_custom_filter_type = None
        self.discriminator = None
        self.system_id = system_id
        if custom_filter_ids is not None:
            self.custom_filter_ids = custom_filter_ids
        if indicator_types is not None:
            self.indicator_types = indicator_types
        if measure_ofs is not None:
            self.measure_ofs = measure_ofs
        if group_ids is not None:
            self.group_ids = group_ids
        if selected_indicator_ids is not None:
            self.selected_indicator_ids = selected_indicator_ids
        if selected_point is not None:
            self.selected_point = selected_point
        if time_range is not None:
            self.time_range = time_range
        if is_custom_filter_type is not None:
            self.is_custom_filter_type = is_custom_filter_type

    @property
    def system_id(self):
        """Gets the system_id of this SessionCreateRequest.  # noqa: E501


        :return: The system_id of this SessionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this SessionCreateRequest.


        :param system_id: The system_id of this SessionCreateRequest.  # noqa: E501
        :type: str
        """
        if system_id is None:
            raise ValueError("Invalid value for `system_id`, must not be `None`")  # noqa: E501

        self._system_id = system_id

    @property
    def custom_filter_ids(self):
        """Gets the custom_filter_ids of this SessionCreateRequest.  # noqa: E501


        :return: The custom_filter_ids of this SessionCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._custom_filter_ids

    @custom_filter_ids.setter
    def custom_filter_ids(self, custom_filter_ids):
        """Sets the custom_filter_ids of this SessionCreateRequest.


        :param custom_filter_ids: The custom_filter_ids of this SessionCreateRequest.  # noqa: E501
        :type: list[str]
        """

        self._custom_filter_ids = custom_filter_ids

    @property
    def indicator_types(self):
        """Gets the indicator_types of this SessionCreateRequest.  # noqa: E501


        :return: The indicator_types of this SessionCreateRequest.  # noqa: E501
        :rtype: list[MetricTypeCodes]
        """
        return self._indicator_types

    @indicator_types.setter
    def indicator_types(self, indicator_types):
        """Sets the indicator_types of this SessionCreateRequest.


        :param indicator_types: The indicator_types of this SessionCreateRequest.  # noqa: E501
        :type: list[MetricTypeCodes]
        """

        self._indicator_types = indicator_types

    @property
    def measure_ofs(self):
        """Gets the measure_ofs of this SessionCreateRequest.  # noqa: E501


        :return: The measure_ofs of this SessionCreateRequest.  # noqa: E501
        :rtype: list[SensorRoleTypeCodes]
        """
        return self._measure_ofs

    @measure_ofs.setter
    def measure_ofs(self, measure_ofs):
        """Sets the measure_ofs of this SessionCreateRequest.


        :param measure_ofs: The measure_ofs of this SessionCreateRequest.  # noqa: E501
        :type: list[SensorRoleTypeCodes]
        """

        self._measure_ofs = measure_ofs

    @property
    def group_ids(self):
        """Gets the group_ids of this SessionCreateRequest.  # noqa: E501


        :return: The group_ids of this SessionCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._group_ids

    @group_ids.setter
    def group_ids(self, group_ids):
        """Sets the group_ids of this SessionCreateRequest.


        :param group_ids: The group_ids of this SessionCreateRequest.  # noqa: E501
        :type: list[str]
        """

        self._group_ids = group_ids

    @property
    def selected_indicator_ids(self):
        """Gets the selected_indicator_ids of this SessionCreateRequest.  # noqa: E501


        :return: The selected_indicator_ids of this SessionCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._selected_indicator_ids

    @selected_indicator_ids.setter
    def selected_indicator_ids(self, selected_indicator_ids):
        """Sets the selected_indicator_ids of this SessionCreateRequest.


        :param selected_indicator_ids: The selected_indicator_ids of this SessionCreateRequest.  # noqa: E501
        :type: list[str]
        """

        self._selected_indicator_ids = selected_indicator_ids

    @property
    def selected_point(self):
        """Gets the selected_point of this SessionCreateRequest.  # noqa: E501


        :return: The selected_point of this SessionCreateRequest.  # noqa: E501
        :rtype: SessionSelectedPointChild
        """
        return self._selected_point

    @selected_point.setter
    def selected_point(self, selected_point):
        """Sets the selected_point of this SessionCreateRequest.


        :param selected_point: The selected_point of this SessionCreateRequest.  # noqa: E501
        :type: SessionSelectedPointChild
        """

        self._selected_point = selected_point

    @property
    def time_range(self):
        """Gets the time_range of this SessionCreateRequest.  # noqa: E501


        :return: The time_range of this SessionCreateRequest.  # noqa: E501
        :rtype: SessionTimeRangeChild
        """
        return self._time_range

    @time_range.setter
    def time_range(self, time_range):
        """Sets the time_range of this SessionCreateRequest.


        :param time_range: The time_range of this SessionCreateRequest.  # noqa: E501
        :type: SessionTimeRangeChild
        """

        self._time_range = time_range

    @property
    def is_custom_filter_type(self):
        """Gets the is_custom_filter_type of this SessionCreateRequest.  # noqa: E501


        :return: The is_custom_filter_type of this SessionCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_custom_filter_type

    @is_custom_filter_type.setter
    def is_custom_filter_type(self, is_custom_filter_type):
        """Sets the is_custom_filter_type of this SessionCreateRequest.


        :param is_custom_filter_type: The is_custom_filter_type of this SessionCreateRequest.  # noqa: E501
        :type: bool
        """

        self._is_custom_filter_type = is_custom_filter_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SessionCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TreeItemResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tree_item_type': 'GroupTypeCodes',
        'sort_order': 'int',
        'has_children': 'bool',
        'alarm_severity_level': 'int',
        'asset_class_code': 'str',
        'is_collector_dependent_system': 'bool',
        'has_alarms': 'bool',
        'has_warnings': 'bool',
        'asset_type': 'AssetTypeChild',
        'asset_category': 'AssetCategoryChild',
        'asset_size': 'AssetSizeChild',
        'parent': 'ParentChild',
        'children': 'list[TreeItemDescendantChild]',
        'hierarchy': 'list[HierarchyChild]',
        'id': 'str',
        'name': 'str',
        'abbreviation': 'str',
        'active': 'bool',
        'is_paused': 'bool',
        'is_snoozed': 'bool',
        'created': 'datetime',
        'corporation': 'CorporationChild',
        'location': 'LocationChild'
    }

    attribute_map = {
        'tree_item_type': 'TreeItemType',
        'sort_order': 'SortOrder',
        'has_children': 'HasChildren',
        'alarm_severity_level': 'AlarmSeverityLevel',
        'asset_class_code': 'AssetClassCode',
        'is_collector_dependent_system': 'IsCollectorDependentSystem',
        'has_alarms': 'HasAlarms',
        'has_warnings': 'HasWarnings',
        'asset_type': 'AssetType',
        'asset_category': 'AssetCategory',
        'asset_size': 'AssetSize',
        'parent': 'Parent',
        'children': 'Children',
        'hierarchy': 'Hierarchy',
        'id': 'Id',
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'active': 'Active',
        'is_paused': 'IsPaused',
        'is_snoozed': 'IsSnoozed',
        'created': 'Created',
        'corporation': 'Corporation',
        'location': 'Location'
    }

    def __init__(self, tree_item_type=None, sort_order=None, has_children=None, alarm_severity_level=None, asset_class_code=None, is_collector_dependent_system=None, has_alarms=None, has_warnings=None, asset_type=None, asset_category=None, asset_size=None, parent=None, children=None, hierarchy=None, id=None, name=None, abbreviation=None, active=None, is_paused=None, is_snoozed=None, created=None, corporation=None, location=None):  # noqa: E501
        """TreeItemResponse - a model defined in Swagger"""  # noqa: E501
        self._tree_item_type = None
        self._sort_order = None
        self._has_children = None
        self._alarm_severity_level = None
        self._asset_class_code = None
        self._is_collector_dependent_system = None
        self._has_alarms = None
        self._has_warnings = None
        self._asset_type = None
        self._asset_category = None
        self._asset_size = None
        self._parent = None
        self._children = None
        self._hierarchy = None
        self._id = None
        self._name = None
        self._abbreviation = None
        self._active = None
        self._is_paused = None
        self._is_snoozed = None
        self._created = None
        self._corporation = None
        self._location = None
        self.discriminator = None
        self.tree_item_type = tree_item_type
        self.sort_order = sort_order
        self.has_children = has_children
        self.alarm_severity_level = alarm_severity_level
        if asset_class_code is not None:
            self.asset_class_code = asset_class_code
        if is_collector_dependent_system is not None:
            self.is_collector_dependent_system = is_collector_dependent_system
        if has_alarms is not None:
            self.has_alarms = has_alarms
        if has_warnings is not None:
            self.has_warnings = has_warnings
        if asset_type is not None:
            self.asset_type = asset_type
        if asset_category is not None:
            self.asset_category = asset_category
        if asset_size is not None:
            self.asset_size = asset_size
        if parent is not None:
            self.parent = parent
        if children is not None:
            self.children = children
        if hierarchy is not None:
            self.hierarchy = hierarchy
        self.id = id
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.active = active
        self.is_paused = is_paused
        self.is_snoozed = is_snoozed
        self.created = created
        self.corporation = corporation
        self.location = location

    @property
    def tree_item_type(self):
        """Gets the tree_item_type of this TreeItemResponse.  # noqa: E501


        :return: The tree_item_type of this TreeItemResponse.  # noqa: E501
        :rtype: GroupTypeCodes
        """
        return self._tree_item_type

    @tree_item_type.setter
    def tree_item_type(self, tree_item_type):
        """Sets the tree_item_type of this TreeItemResponse.


        :param tree_item_type: The tree_item_type of this TreeItemResponse.  # noqa: E501
        :type: GroupTypeCodes
        """
        if tree_item_type is None:
            raise ValueError("Invalid value for `tree_item_type`, must not be `None`")  # noqa: E501

        self._tree_item_type = tree_item_type

    @property
    def sort_order(self):
        """Gets the sort_order of this TreeItemResponse.  # noqa: E501


        :return: The sort_order of this TreeItemResponse.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this TreeItemResponse.


        :param sort_order: The sort_order of this TreeItemResponse.  # noqa: E501
        :type: int
        """
        if sort_order is None:
            raise ValueError("Invalid value for `sort_order`, must not be `None`")  # noqa: E501

        self._sort_order = sort_order

    @property
    def has_children(self):
        """Gets the has_children of this TreeItemResponse.  # noqa: E501


        :return: The has_children of this TreeItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_children

    @has_children.setter
    def has_children(self, has_children):
        """Sets the has_children of this TreeItemResponse.


        :param has_children: The has_children of this TreeItemResponse.  # noqa: E501
        :type: bool
        """
        if has_children is None:
            raise ValueError("Invalid value for `has_children`, must not be `None`")  # noqa: E501

        self._has_children = has_children

    @property
    def alarm_severity_level(self):
        """Gets the alarm_severity_level of this TreeItemResponse.  # noqa: E501


        :return: The alarm_severity_level of this TreeItemResponse.  # noqa: E501
        :rtype: int
        """
        return self._alarm_severity_level

    @alarm_severity_level.setter
    def alarm_severity_level(self, alarm_severity_level):
        """Sets the alarm_severity_level of this TreeItemResponse.


        :param alarm_severity_level: The alarm_severity_level of this TreeItemResponse.  # noqa: E501
        :type: int
        """
        if alarm_severity_level is None:
            raise ValueError("Invalid value for `alarm_severity_level`, must not be `None`")  # noqa: E501

        self._alarm_severity_level = alarm_severity_level

    @property
    def asset_class_code(self):
        """Gets the asset_class_code of this TreeItemResponse.  # noqa: E501


        :return: The asset_class_code of this TreeItemResponse.  # noqa: E501
        :rtype: str
        """
        return self._asset_class_code

    @asset_class_code.setter
    def asset_class_code(self, asset_class_code):
        """Sets the asset_class_code of this TreeItemResponse.


        :param asset_class_code: The asset_class_code of this TreeItemResponse.  # noqa: E501
        :type: str
        """

        self._asset_class_code = asset_class_code

    @property
    def is_collector_dependent_system(self):
        """Gets the is_collector_dependent_system of this TreeItemResponse.  # noqa: E501


        :return: The is_collector_dependent_system of this TreeItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_collector_dependent_system

    @is_collector_dependent_system.setter
    def is_collector_dependent_system(self, is_collector_dependent_system):
        """Sets the is_collector_dependent_system of this TreeItemResponse.


        :param is_collector_dependent_system: The is_collector_dependent_system of this TreeItemResponse.  # noqa: E501
        :type: bool
        """

        self._is_collector_dependent_system = is_collector_dependent_system

    @property
    def has_alarms(self):
        """Gets the has_alarms of this TreeItemResponse.  # noqa: E501


        :return: The has_alarms of this TreeItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_alarms

    @has_alarms.setter
    def has_alarms(self, has_alarms):
        """Sets the has_alarms of this TreeItemResponse.


        :param has_alarms: The has_alarms of this TreeItemResponse.  # noqa: E501
        :type: bool
        """

        self._has_alarms = has_alarms

    @property
    def has_warnings(self):
        """Gets the has_warnings of this TreeItemResponse.  # noqa: E501


        :return: The has_warnings of this TreeItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._has_warnings

    @has_warnings.setter
    def has_warnings(self, has_warnings):
        """Sets the has_warnings of this TreeItemResponse.


        :param has_warnings: The has_warnings of this TreeItemResponse.  # noqa: E501
        :type: bool
        """

        self._has_warnings = has_warnings

    @property
    def asset_type(self):
        """Gets the asset_type of this TreeItemResponse.  # noqa: E501


        :return: The asset_type of this TreeItemResponse.  # noqa: E501
        :rtype: AssetTypeChild
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this TreeItemResponse.


        :param asset_type: The asset_type of this TreeItemResponse.  # noqa: E501
        :type: AssetTypeChild
        """

        self._asset_type = asset_type

    @property
    def asset_category(self):
        """Gets the asset_category of this TreeItemResponse.  # noqa: E501


        :return: The asset_category of this TreeItemResponse.  # noqa: E501
        :rtype: AssetCategoryChild
        """
        return self._asset_category

    @asset_category.setter
    def asset_category(self, asset_category):
        """Sets the asset_category of this TreeItemResponse.


        :param asset_category: The asset_category of this TreeItemResponse.  # noqa: E501
        :type: AssetCategoryChild
        """

        self._asset_category = asset_category

    @property
    def asset_size(self):
        """Gets the asset_size of this TreeItemResponse.  # noqa: E501


        :return: The asset_size of this TreeItemResponse.  # noqa: E501
        :rtype: AssetSizeChild
        """
        return self._asset_size

    @asset_size.setter
    def asset_size(self, asset_size):
        """Sets the asset_size of this TreeItemResponse.


        :param asset_size: The asset_size of this TreeItemResponse.  # noqa: E501
        :type: AssetSizeChild
        """

        self._asset_size = asset_size

    @property
    def parent(self):
        """Gets the parent of this TreeItemResponse.  # noqa: E501


        :return: The parent of this TreeItemResponse.  # noqa: E501
        :rtype: ParentChild
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this TreeItemResponse.


        :param parent: The parent of this TreeItemResponse.  # noqa: E501
        :type: ParentChild
        """

        self._parent = parent

    @property
    def children(self):
        """Gets the children of this TreeItemResponse.  # noqa: E501


        :return: The children of this TreeItemResponse.  # noqa: E501
        :rtype: list[TreeItemDescendantChild]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this TreeItemResponse.


        :param children: The children of this TreeItemResponse.  # noqa: E501
        :type: list[TreeItemDescendantChild]
        """

        self._children = children

    @property
    def hierarchy(self):
        """Gets the hierarchy of this TreeItemResponse.  # noqa: E501


        :return: The hierarchy of this TreeItemResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this TreeItemResponse.


        :param hierarchy: The hierarchy of this TreeItemResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """

        self._hierarchy = hierarchy

    @property
    def id(self):
        """Gets the id of this TreeItemResponse.  # noqa: E501


        :return: The id of this TreeItemResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TreeItemResponse.


        :param id: The id of this TreeItemResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this TreeItemResponse.  # noqa: E501


        :return: The name of this TreeItemResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TreeItemResponse.


        :param name: The name of this TreeItemResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this TreeItemResponse.  # noqa: E501


        :return: The abbreviation of this TreeItemResponse.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this TreeItemResponse.


        :param abbreviation: The abbreviation of this TreeItemResponse.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def active(self):
        """Gets the active of this TreeItemResponse.  # noqa: E501


        :return: The active of this TreeItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this TreeItemResponse.


        :param active: The active of this TreeItemResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def is_paused(self):
        """Gets the is_paused of this TreeItemResponse.  # noqa: E501


        :return: The is_paused of this TreeItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this TreeItemResponse.


        :param is_paused: The is_paused of this TreeItemResponse.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def is_snoozed(self):
        """Gets the is_snoozed of this TreeItemResponse.  # noqa: E501


        :return: The is_snoozed of this TreeItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_snoozed

    @is_snoozed.setter
    def is_snoozed(self, is_snoozed):
        """Sets the is_snoozed of this TreeItemResponse.


        :param is_snoozed: The is_snoozed of this TreeItemResponse.  # noqa: E501
        :type: bool
        """
        if is_snoozed is None:
            raise ValueError("Invalid value for `is_snoozed`, must not be `None`")  # noqa: E501

        self._is_snoozed = is_snoozed

    @property
    def created(self):
        """Gets the created of this TreeItemResponse.  # noqa: E501


        :return: The created of this TreeItemResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this TreeItemResponse.


        :param created: The created of this TreeItemResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def corporation(self):
        """Gets the corporation of this TreeItemResponse.  # noqa: E501


        :return: The corporation of this TreeItemResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this TreeItemResponse.


        :param corporation: The corporation of this TreeItemResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    @property
    def location(self):
        """Gets the location of this TreeItemResponse.  # noqa: E501


        :return: The location of this TreeItemResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this TreeItemResponse.


        :param location: The location of this TreeItemResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TreeItemResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TreeItemResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.indicators_api import IndicatorsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestIndicatorsApi(unittest.TestCase):
    """IndicatorsApi unit test stubs"""

    def setUp(self):
        self.api = IndicatorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_burst_data_audio(self):
        """Test case for get_burst_data_audio

        Generates audio from Indicator burst data.  Only vibration Indicators are supported.  # noqa: E501
        """
        pass

    def test_get_indicator(self):
        """Test case for get_indicator

        Gets an indicator response  # noqa: E501
        """
        pass

    def test_get_indicator_alarm_state(self):
        """Test case for get_indicator_alarm_state

        Get the alarm state for a specific indicator  # noqa: E501
        """
        pass

    def test_get_indicator_statistics(self):
        """Test case for get_indicator_statistics

        Gets indicator statistics  # noqa: E501
        """
        pass

    def test_get_indicator_types(self):
        """Test case for get_indicator_types

        Gets indicator types  # noqa: E501
        """
        pass

    def test_get_indicators(self):
        """Test case for get_indicators

        Gets indicator responses  # noqa: E501
        """
        pass

    def test_get_indicators_alarm_state(self):
        """Test case for get_indicators_alarm_state

        Get the alarm state for a list of indicators  # noqa: E501
        """
        pass

    def test_get_measure_ofs_for_indicator(self):
        """Test case for get_measure_ofs_for_indicator

        Returns a list of measureOf values and their UI-friendly format  # noqa: E501
        """
        pass

    def test_get_options_for_indicator(self):
        """Test case for get_options_for_indicator

        Gets options for indicators  # noqa: E501
        """
        pass

    def test_get_statistics_for_indicator(self):
        """Test case for get_statistics_for_indicator

        Gets statistics for a specific indicator  # noqa: E501
        """
        pass

    def test_set_smart_alarms(self):
        """Test case for set_smart_alarms

        Calculates and sets smart alarms for the given indicator.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BaselineWithSignificantDigitsChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'baseline_value_with_significant_digits': 'str',
        'baseline_value': 'float',
        'baseline_range_end_date': 'datetime',
        'baseline_range_start_date': 'datetime',
        'baseline_error': 'str',
        'baseline_type': 'str',
        'baseline_state': 'str',
        'baseline_sampling_frequency': 'int'
    }

    attribute_map = {
        'baseline_value_with_significant_digits': 'BaselineValueWithSignificantDigits',
        'baseline_value': 'BaselineValue',
        'baseline_range_end_date': 'BaselineRangeEndDate',
        'baseline_range_start_date': 'BaselineRangeStartDate',
        'baseline_error': 'BaselineError',
        'baseline_type': 'BaselineType',
        'baseline_state': 'BaselineState',
        'baseline_sampling_frequency': 'BaselineSamplingFrequency'
    }

    def __init__(self, baseline_value_with_significant_digits=None, baseline_value=None, baseline_range_end_date=None, baseline_range_start_date=None, baseline_error=None, baseline_type=None, baseline_state=None, baseline_sampling_frequency=None):  # noqa: E501
        """BaselineWithSignificantDigitsChild - a model defined in Swagger"""  # noqa: E501
        self._baseline_value_with_significant_digits = None
        self._baseline_value = None
        self._baseline_range_end_date = None
        self._baseline_range_start_date = None
        self._baseline_error = None
        self._baseline_type = None
        self._baseline_state = None
        self._baseline_sampling_frequency = None
        self.discriminator = None
        if baseline_value_with_significant_digits is not None:
            self.baseline_value_with_significant_digits = baseline_value_with_significant_digits
        if baseline_value is not None:
            self.baseline_value = baseline_value
        if baseline_range_end_date is not None:
            self.baseline_range_end_date = baseline_range_end_date
        if baseline_range_start_date is not None:
            self.baseline_range_start_date = baseline_range_start_date
        if baseline_error is not None:
            self.baseline_error = baseline_error
        if baseline_type is not None:
            self.baseline_type = baseline_type
        if baseline_state is not None:
            self.baseline_state = baseline_state
        if baseline_sampling_frequency is not None:
            self.baseline_sampling_frequency = baseline_sampling_frequency

    @property
    def baseline_value_with_significant_digits(self):
        """Gets the baseline_value_with_significant_digits of this BaselineWithSignificantDigitsChild.  # noqa: E501

        Formats the baseline value to use significant digits  # noqa: E501

        :return: The baseline_value_with_significant_digits of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :rtype: str
        """
        return self._baseline_value_with_significant_digits

    @baseline_value_with_significant_digits.setter
    def baseline_value_with_significant_digits(self, baseline_value_with_significant_digits):
        """Sets the baseline_value_with_significant_digits of this BaselineWithSignificantDigitsChild.

        Formats the baseline value to use significant digits  # noqa: E501

        :param baseline_value_with_significant_digits: The baseline_value_with_significant_digits of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :type: str
        """

        self._baseline_value_with_significant_digits = baseline_value_with_significant_digits

    @property
    def baseline_value(self):
        """Gets the baseline_value of this BaselineWithSignificantDigitsChild.  # noqa: E501

        Baseline Value (aka Baseline Number) for a given Damage indicator  # noqa: E501

        :return: The baseline_value of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :rtype: float
        """
        return self._baseline_value

    @baseline_value.setter
    def baseline_value(self, baseline_value):
        """Sets the baseline_value of this BaselineWithSignificantDigitsChild.

        Baseline Value (aka Baseline Number) for a given Damage indicator  # noqa: E501

        :param baseline_value: The baseline_value of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :type: float
        """

        self._baseline_value = baseline_value

    @property
    def baseline_range_end_date(self):
        """Gets the baseline_range_end_date of this BaselineWithSignificantDigitsChild.  # noqa: E501

        The ending date of the baseline.  Will be null when the BaselineType is Single  # noqa: E501

        :return: The baseline_range_end_date of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :rtype: datetime
        """
        return self._baseline_range_end_date

    @baseline_range_end_date.setter
    def baseline_range_end_date(self, baseline_range_end_date):
        """Sets the baseline_range_end_date of this BaselineWithSignificantDigitsChild.

        The ending date of the baseline.  Will be null when the BaselineType is Single  # noqa: E501

        :param baseline_range_end_date: The baseline_range_end_date of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :type: datetime
        """

        self._baseline_range_end_date = baseline_range_end_date

    @property
    def baseline_range_start_date(self):
        """Gets the baseline_range_start_date of this BaselineWithSignificantDigitsChild.  # noqa: E501

        The starting date for the baseline  # noqa: E501

        :return: The baseline_range_start_date of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :rtype: datetime
        """
        return self._baseline_range_start_date

    @baseline_range_start_date.setter
    def baseline_range_start_date(self, baseline_range_start_date):
        """Sets the baseline_range_start_date of this BaselineWithSignificantDigitsChild.

        The starting date for the baseline  # noqa: E501

        :param baseline_range_start_date: The baseline_range_start_date of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :type: datetime
        """

        self._baseline_range_start_date = baseline_range_start_date

    @property
    def baseline_error(self):
        """Gets the baseline_error of this BaselineWithSignificantDigitsChild.  # noqa: E501

        Description of the error, if any occurred  # noqa: E501

        :return: The baseline_error of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :rtype: str
        """
        return self._baseline_error

    @baseline_error.setter
    def baseline_error(self, baseline_error):
        """Sets the baseline_error of this BaselineWithSignificantDigitsChild.

        Description of the error, if any occurred  # noqa: E501

        :param baseline_error: The baseline_error of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :type: str
        """

        self._baseline_error = baseline_error

    @property
    def baseline_type(self):
        """Gets the baseline_type of this BaselineWithSignificantDigitsChild.  # noqa: E501

        The type of baseline taken being either single, range, or none  # noqa: E501

        :return: The baseline_type of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :rtype: str
        """
        return self._baseline_type

    @baseline_type.setter
    def baseline_type(self, baseline_type):
        """Sets the baseline_type of this BaselineWithSignificantDigitsChild.

        The type of baseline taken being either single, range, or none  # noqa: E501

        :param baseline_type: The baseline_type of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :type: str
        """

        self._baseline_type = baseline_type

    @property
    def baseline_state(self):
        """Gets the baseline_state of this BaselineWithSignificantDigitsChild.  # noqa: E501

        The state of the baseline. Whether the baseline is complete, has an error, or does not exist.  # noqa: E501

        :return: The baseline_state of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :rtype: str
        """
        return self._baseline_state

    @baseline_state.setter
    def baseline_state(self, baseline_state):
        """Sets the baseline_state of this BaselineWithSignificantDigitsChild.

        The state of the baseline. Whether the baseline is complete, has an error, or does not exist.  # noqa: E501

        :param baseline_state: The baseline_state of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :type: str
        """

        self._baseline_state = baseline_state

    @property
    def baseline_sampling_frequency(self):
        """Gets the baseline_sampling_frequency of this BaselineWithSignificantDigitsChild.  # noqa: E501

        Defines how often the number of samples are taken for the baseline  # noqa: E501

        :return: The baseline_sampling_frequency of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :rtype: int
        """
        return self._baseline_sampling_frequency

    @baseline_sampling_frequency.setter
    def baseline_sampling_frequency(self, baseline_sampling_frequency):
        """Sets the baseline_sampling_frequency of this BaselineWithSignificantDigitsChild.

        Defines how often the number of samples are taken for the baseline  # noqa: E501

        :param baseline_sampling_frequency: The baseline_sampling_frequency of this BaselineWithSignificantDigitsChild.  # noqa: E501
        :type: int
        """

        self._baseline_sampling_frequency = baseline_sampling_frequency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BaselineWithSignificantDigitsChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaselineWithSignificantDigitsChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PagedResultsModelActivityEventResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'result': 'list[ActivityEventResponse]',
        'total': 'int',
        'total_pages': 'int',
        'current_page': 'int',
        'page_size': 'int'
    }

    attribute_map = {
        'result': 'Result',
        'total': 'Total',
        'total_pages': 'TotalPages',
        'current_page': 'CurrentPage',
        'page_size': 'PageSize'
    }

    def __init__(self, result=None, total=None, total_pages=None, current_page=None, page_size=None):  # noqa: E501
        """PagedResultsModelActivityEventResponse - a model defined in Swagger"""  # noqa: E501
        self._result = None
        self._total = None
        self._total_pages = None
        self._current_page = None
        self._page_size = None
        self.discriminator = None
        self.result = result
        self.total = total
        self.total_pages = total_pages
        self.current_page = current_page
        self.page_size = page_size

    @property
    def result(self):
        """Gets the result of this PagedResultsModelActivityEventResponse.  # noqa: E501

        The items in the current page.  # noqa: E501

        :return: The result of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :rtype: list[ActivityEventResponse]
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this PagedResultsModelActivityEventResponse.

        The items in the current page.  # noqa: E501

        :param result: The result of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :type: list[ActivityEventResponse]
        """
        if result is None:
            raise ValueError("Invalid value for `result`, must not be `None`")  # noqa: E501

        self._result = result

    @property
    def total(self):
        """Gets the total of this PagedResultsModelActivityEventResponse.  # noqa: E501

        The total number of items in the query.  # noqa: E501

        :return: The total of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this PagedResultsModelActivityEventResponse.

        The total number of items in the query.  # noqa: E501

        :param total: The total of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :type: int
        """
        if total is None:
            raise ValueError("Invalid value for `total`, must not be `None`")  # noqa: E501

        self._total = total

    @property
    def total_pages(self):
        """Gets the total_pages of this PagedResultsModelActivityEventResponse.  # noqa: E501

        The total number of pages in the query.  # noqa: E501

        :return: The total_pages of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PagedResultsModelActivityEventResponse.

        The total number of pages in the query.  # noqa: E501

        :param total_pages: The total_pages of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :type: int
        """
        if total_pages is None:
            raise ValueError("Invalid value for `total_pages`, must not be `None`")  # noqa: E501

        self._total_pages = total_pages

    @property
    def current_page(self):
        """Gets the current_page of this PagedResultsModelActivityEventResponse.  # noqa: E501

        The page number for the current set of results.  # noqa: E501

        :return: The current_page of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :rtype: int
        """
        return self._current_page

    @current_page.setter
    def current_page(self, current_page):
        """Sets the current_page of this PagedResultsModelActivityEventResponse.

        The page number for the current set of results.  # noqa: E501

        :param current_page: The current_page of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :type: int
        """
        if current_page is None:
            raise ValueError("Invalid value for `current_page`, must not be `None`")  # noqa: E501

        self._current_page = current_page

    @property
    def page_size(self):
        """Gets the page_size of this PagedResultsModelActivityEventResponse.  # noqa: E501

        The size of each result set.  # noqa: E501

        :return: The page_size of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this PagedResultsModelActivityEventResponse.

        The size of each result set.  # noqa: E501

        :param page_size: The page_size of this PagedResultsModelActivityEventResponse.  # noqa: E501
        :type: int
        """
        if page_size is None:
            raise ValueError("Invalid value for `page_size`, must not be `None`")  # noqa: E501

        self._page_size = page_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PagedResultsModelActivityEventResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PagedResultsModelActivityEventResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.dashboards_api import DashboardsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestDashboardsApi(unittest.TestCase):
    """DashboardsApi unit test stubs"""

    def setUp(self):
        self.api = DashboardsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_dashboard(self):
        """Test case for create_dashboard

        Creates a new dashboard  # noqa: E501
        """
        pass

    def test_delete_dashboard(self):
        """Test case for delete_dashboard

        Deletes a dashboard  # noqa: E501
        """
        pass

    def test_get_dashboard(self):
        """Test case for get_dashboard

        """
        pass

    def test_get_dashboard_templates(self):
        """Test case for get_dashboard_templates

        Gets dashboard templates  # noqa: E501
        """
        pass

    def test_get_dashboards(self):
        """Test case for get_dashboards

        Gets all dashboards available to the user  # noqa: E501
        """
        pass

    def test_update_dashboard(self):
        """Test case for update_dashboard

        Updates a dashboard  # noqa: E501
        """
        pass

    def test_update_dashboard_permissions(self):
        """Test case for update_dashboard_permissions

        Updates dashboard permissions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DashboardResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'is_sentry_managed': 'bool',
        'is_visible_to_customers': 'bool',
        'created': 'datetime',
        'updated': 'datetime',
        'created_by': 'UserChild',
        'updated_by': 'UserChild',
        'dashboard_type': 'DashboardTypeChild',
        'corporation': 'PrimaryCorporationChild',
        'location': 'LocationChild',
        'dashboard_widgets': 'list[DashboardWidgetChild]',
        'power_bi_report': 'PowerBiReportChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'description': 'Description',
        'is_sentry_managed': 'IsSentryManaged',
        'is_visible_to_customers': 'IsVisibleToCustomers',
        'created': 'Created',
        'updated': 'Updated',
        'created_by': 'CreatedBy',
        'updated_by': 'UpdatedBy',
        'dashboard_type': 'DashboardType',
        'corporation': 'Corporation',
        'location': 'Location',
        'dashboard_widgets': 'DashboardWidgets',
        'power_bi_report': 'PowerBiReport'
    }

    def __init__(self, id=None, name=None, description=None, is_sentry_managed=None, is_visible_to_customers=None, created=None, updated=None, created_by=None, updated_by=None, dashboard_type=None, corporation=None, location=None, dashboard_widgets=None, power_bi_report=None):  # noqa: E501
        """DashboardResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._description = None
        self._is_sentry_managed = None
        self._is_visible_to_customers = None
        self._created = None
        self._updated = None
        self._created_by = None
        self._updated_by = None
        self._dashboard_type = None
        self._corporation = None
        self._location = None
        self._dashboard_widgets = None
        self._power_bi_report = None
        self.discriminator = None
        self.id = id
        self.name = name
        if description is not None:
            self.description = description
        self.is_sentry_managed = is_sentry_managed
        self.is_visible_to_customers = is_visible_to_customers
        self.created = created
        self.updated = updated
        if created_by is not None:
            self.created_by = created_by
        if updated_by is not None:
            self.updated_by = updated_by
        if dashboard_type is not None:
            self.dashboard_type = dashboard_type
        if corporation is not None:
            self.corporation = corporation
        if location is not None:
            self.location = location
        if dashboard_widgets is not None:
            self.dashboard_widgets = dashboard_widgets
        if power_bi_report is not None:
            self.power_bi_report = power_bi_report

    @property
    def id(self):
        """Gets the id of this DashboardResponse.  # noqa: E501


        :return: The id of this DashboardResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DashboardResponse.


        :param id: The id of this DashboardResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this DashboardResponse.  # noqa: E501


        :return: The name of this DashboardResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DashboardResponse.


        :param name: The name of this DashboardResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this DashboardResponse.  # noqa: E501


        :return: The description of this DashboardResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DashboardResponse.


        :param description: The description of this DashboardResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def is_sentry_managed(self):
        """Gets the is_sentry_managed of this DashboardResponse.  # noqa: E501


        :return: The is_sentry_managed of this DashboardResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_sentry_managed

    @is_sentry_managed.setter
    def is_sentry_managed(self, is_sentry_managed):
        """Sets the is_sentry_managed of this DashboardResponse.


        :param is_sentry_managed: The is_sentry_managed of this DashboardResponse.  # noqa: E501
        :type: bool
        """
        if is_sentry_managed is None:
            raise ValueError("Invalid value for `is_sentry_managed`, must not be `None`")  # noqa: E501

        self._is_sentry_managed = is_sentry_managed

    @property
    def is_visible_to_customers(self):
        """Gets the is_visible_to_customers of this DashboardResponse.  # noqa: E501


        :return: The is_visible_to_customers of this DashboardResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible_to_customers

    @is_visible_to_customers.setter
    def is_visible_to_customers(self, is_visible_to_customers):
        """Sets the is_visible_to_customers of this DashboardResponse.


        :param is_visible_to_customers: The is_visible_to_customers of this DashboardResponse.  # noqa: E501
        :type: bool
        """
        if is_visible_to_customers is None:
            raise ValueError("Invalid value for `is_visible_to_customers`, must not be `None`")  # noqa: E501

        self._is_visible_to_customers = is_visible_to_customers

    @property
    def created(self):
        """Gets the created of this DashboardResponse.  # noqa: E501


        :return: The created of this DashboardResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DashboardResponse.


        :param created: The created of this DashboardResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this DashboardResponse.  # noqa: E501


        :return: The updated of this DashboardResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this DashboardResponse.


        :param updated: The updated of this DashboardResponse.  # noqa: E501
        :type: datetime
        """
        if updated is None:
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def created_by(self):
        """Gets the created_by of this DashboardResponse.  # noqa: E501


        :return: The created_by of this DashboardResponse.  # noqa: E501
        :rtype: UserChild
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this DashboardResponse.


        :param created_by: The created_by of this DashboardResponse.  # noqa: E501
        :type: UserChild
        """

        self._created_by = created_by

    @property
    def updated_by(self):
        """Gets the updated_by of this DashboardResponse.  # noqa: E501


        :return: The updated_by of this DashboardResponse.  # noqa: E501
        :rtype: UserChild
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this DashboardResponse.


        :param updated_by: The updated_by of this DashboardResponse.  # noqa: E501
        :type: UserChild
        """

        self._updated_by = updated_by

    @property
    def dashboard_type(self):
        """Gets the dashboard_type of this DashboardResponse.  # noqa: E501


        :return: The dashboard_type of this DashboardResponse.  # noqa: E501
        :rtype: DashboardTypeChild
        """
        return self._dashboard_type

    @dashboard_type.setter
    def dashboard_type(self, dashboard_type):
        """Sets the dashboard_type of this DashboardResponse.


        :param dashboard_type: The dashboard_type of this DashboardResponse.  # noqa: E501
        :type: DashboardTypeChild
        """

        self._dashboard_type = dashboard_type

    @property
    def corporation(self):
        """Gets the corporation of this DashboardResponse.  # noqa: E501


        :return: The corporation of this DashboardResponse.  # noqa: E501
        :rtype: PrimaryCorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this DashboardResponse.


        :param corporation: The corporation of this DashboardResponse.  # noqa: E501
        :type: PrimaryCorporationChild
        """

        self._corporation = corporation

    @property
    def location(self):
        """Gets the location of this DashboardResponse.  # noqa: E501


        :return: The location of this DashboardResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this DashboardResponse.


        :param location: The location of this DashboardResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    @property
    def dashboard_widgets(self):
        """Gets the dashboard_widgets of this DashboardResponse.  # noqa: E501


        :return: The dashboard_widgets of this DashboardResponse.  # noqa: E501
        :rtype: list[DashboardWidgetChild]
        """
        return self._dashboard_widgets

    @dashboard_widgets.setter
    def dashboard_widgets(self, dashboard_widgets):
        """Sets the dashboard_widgets of this DashboardResponse.


        :param dashboard_widgets: The dashboard_widgets of this DashboardResponse.  # noqa: E501
        :type: list[DashboardWidgetChild]
        """

        self._dashboard_widgets = dashboard_widgets

    @property
    def power_bi_report(self):
        """Gets the power_bi_report of this DashboardResponse.  # noqa: E501


        :return: The power_bi_report of this DashboardResponse.  # noqa: E501
        :rtype: PowerBiReportChild
        """
        return self._power_bi_report

    @power_bi_report.setter
    def power_bi_report(self, power_bi_report):
        """Sets the power_bi_report of this DashboardResponse.


        :param power_bi_report: The power_bi_report of this DashboardResponse.  # noqa: E501
        :type: PowerBiReportChild
        """

        self._power_bi_report = power_bi_report

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetCategoryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'short_name': 'str',
        'code': 'str',
        'active': 'bool',
        'parent_category': 'AssetCategoryParentChild',
        'asset_type': 'AssetTypeChild',
        'parameter_count': 'int'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'short_name': 'ShortName',
        'code': 'Code',
        'active': 'Active',
        'parent_category': 'ParentCategory',
        'asset_type': 'AssetType',
        'parameter_count': 'ParameterCount'
    }

    def __init__(self, id=None, name=None, short_name=None, code=None, active=None, parent_category=None, asset_type=None, parameter_count=None):  # noqa: E501
        """AssetCategoryResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._short_name = None
        self._code = None
        self._active = None
        self._parent_category = None
        self._asset_type = None
        self._parameter_count = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.short_name = short_name
        if code is not None:
            self.code = code
        self.active = active
        if parent_category is not None:
            self.parent_category = parent_category
        self.asset_type = asset_type
        self.parameter_count = parameter_count

    @property
    def id(self):
        """Gets the id of this AssetCategoryResponse.  # noqa: E501


        :return: The id of this AssetCategoryResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AssetCategoryResponse.


        :param id: The id of this AssetCategoryResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this AssetCategoryResponse.  # noqa: E501


        :return: The name of this AssetCategoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AssetCategoryResponse.


        :param name: The name of this AssetCategoryResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def short_name(self):
        """Gets the short_name of this AssetCategoryResponse.  # noqa: E501


        :return: The short_name of this AssetCategoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._short_name

    @short_name.setter
    def short_name(self, short_name):
        """Sets the short_name of this AssetCategoryResponse.


        :param short_name: The short_name of this AssetCategoryResponse.  # noqa: E501
        :type: str
        """
        if short_name is None:
            raise ValueError("Invalid value for `short_name`, must not be `None`")  # noqa: E501

        self._short_name = short_name

    @property
    def code(self):
        """Gets the code of this AssetCategoryResponse.  # noqa: E501


        :return: The code of this AssetCategoryResponse.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this AssetCategoryResponse.


        :param code: The code of this AssetCategoryResponse.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def active(self):
        """Gets the active of this AssetCategoryResponse.  # noqa: E501


        :return: The active of this AssetCategoryResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this AssetCategoryResponse.


        :param active: The active of this AssetCategoryResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def parent_category(self):
        """Gets the parent_category of this AssetCategoryResponse.  # noqa: E501


        :return: The parent_category of this AssetCategoryResponse.  # noqa: E501
        :rtype: AssetCategoryParentChild
        """
        return self._parent_category

    @parent_category.setter
    def parent_category(self, parent_category):
        """Sets the parent_category of this AssetCategoryResponse.


        :param parent_category: The parent_category of this AssetCategoryResponse.  # noqa: E501
        :type: AssetCategoryParentChild
        """

        self._parent_category = parent_category

    @property
    def asset_type(self):
        """Gets the asset_type of this AssetCategoryResponse.  # noqa: E501


        :return: The asset_type of this AssetCategoryResponse.  # noqa: E501
        :rtype: AssetTypeChild
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this AssetCategoryResponse.


        :param asset_type: The asset_type of this AssetCategoryResponse.  # noqa: E501
        :type: AssetTypeChild
        """
        if asset_type is None:
            raise ValueError("Invalid value for `asset_type`, must not be `None`")  # noqa: E501

        self._asset_type = asset_type

    @property
    def parameter_count(self):
        """Gets the parameter_count of this AssetCategoryResponse.  # noqa: E501


        :return: The parameter_count of this AssetCategoryResponse.  # noqa: E501
        :rtype: int
        """
        return self._parameter_count

    @parameter_count.setter
    def parameter_count(self, parameter_count):
        """Sets the parameter_count of this AssetCategoryResponse.


        :param parameter_count: The parameter_count of this AssetCategoryResponse.  # noqa: E501
        :type: int
        """
        if parameter_count is None:
            raise ValueError("Invalid value for `parameter_count`, must not be `None`")  # noqa: E501

        self._parameter_count = parameter_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetCategoryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetCategoryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
